summaryrefslogtreecommitdiff
path: root/cmd
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2025-07-19 17:06:36 +0300
committerPaul Buetow <paul@buetow.org>2025-07-19 17:06:36 +0300
commitd663a312ff5f45513a23adf9eb9ffb29377bbad9 (patch)
treef88d4beb3905cab49887081ff5559b2db7ea1c33 /cmd
parent77538381c28e4de8fa7d3f3731412c97699bb889 (diff)
feat: improve export functionality and fix configuration issues
- Add custom export directory selection in GUI export dialog - Change default export directory from ~/.local/state/totalrecall to ~/Downloads - Remove broken voice configuration from config file (voice is always random) - Fix discrepancies between code defaults and example config - Remove unimplemented image cache settings from example config The voice configuration was not working due to a bug where it only read from config if the command-line flag was set to "nova" (but default was empty string). Since voices are randomly selected anyway, this configuration option has been removed. 🤖 Generated with [Claude Code](https://claude.ai/code) Co-Authored-By: Claude <noreply@anthropic.com>
Diffstat (limited to 'cmd')
-rw-r--r--cmd/totalrecall/main.go8
1 files changed, 3 insertions, 5 deletions
diff --git a/cmd/totalrecall/main.go b/cmd/totalrecall/main.go
index f8039a8..f50750f 100644
--- a/cmd/totalrecall/main.go
+++ b/cmd/totalrecall/main.go
@@ -73,9 +73,9 @@ func init() {
// Initialize random number generator
rand.Seed(time.Now().UnixNano())
// Set default output directory
home, _ := os.UserHomeDir()
- defaultOutputDir := filepath.Join(home, ".local", "state", "totalrecall")
+ defaultOutputDir := filepath.Join(home, "Downloads")
// Global flags
rootCmd.PersistentFlags().StringVar(&cfgFile, "config", "", "config file (default is $HOME/.totalrecall.yaml)")
@@ -384,9 +384,7 @@ func generateAudioWithVoice(word, voice string) error {
if openAIModel == "gpt-4o-mini-tts" && viper.IsSet("audio.openai_model") {
providerConfig.OpenAIModel = viper.GetString("audio.openai_model")
}
- if openAIVoice == "nova" && viper.IsSet("audio.openai_voice") {
- providerConfig.OpenAIVoice = viper.GetString("audio.openai_voice")
- }
+ // Voice is always random or specified via command line, not from config
if openAISpeed == 0.9 && viper.IsSet("audio.openai_speed") {
providerConfig.OpenAISpeed = viper.GetFloat64("audio.openai_speed")
}
@@ -73,9 +73,9 @@ func init() {
// Initialize random number generator
rand.Seed(time.Now().UnixNano())
- // Set default output directory
+ // Set default output directory to Downloads
home, _ := os.UserHomeDir()